"""
==========================================================
MKLpy: A framework for Multiple Kernel Learning for Python
==========================================================

MKLpy is a framework for Multiple Kernel Learning and Kernel Learning for python
based on numpy, scikit-learn and cvxopt.

authos: Lauriola Ivano ivano.lauriola @phd.unipd.it
"""


__all__ = [
    'algorithms',
    'metrics',
    'preprocessing',
    'utils',
    'arrange',
    'callbacks',
    'generators',
    'model_selection',
    'multiclass',
    'scheduler',
]
